@@ -139,12 +139,16 @@ menu = PluginMenu(
     label="NetBox Storage",
     groups=(
         (
-            "Volume Configuration",
+            "General Configuration",
             (
                 filesystem_menu_item,
+            ),
+        ),
+        (
+            "Linux Volume Configuration",
+            (
                 logicalvolume_menu_item,
                 volumegroup_menu_item,
-                partition_menu_item,
                 physicalvolume_menu_item,
             ),
         ),
@@ -152,6 +156,7 @@ menu = PluginMenu(
             "Storage Configuration",
             (
                 drive_menu_item,
+                partition_menu_item,
             ),
         ),
 
